==> scons_4.0.1%2Bdfsg.orig.tar.xz: scons-4.0.1+dfsg/test/textfile/issue-3550.py <==
#!/usr/bin/env python
#
# __COPYRIGHT__
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
# KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
# WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
# WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#

__revision__ = "__FILE__ __REVISION__ __DATE__ __DEVELOPER__"
"""
Test for GH Issue 3550

 You can't pass a Windows path in a value to be interpolated, 
 because SCons will try to pass it through re.sub which rejects certain character sequences.
"""

import TestSCons

test = TestSCons.TestSCons()

match_mode = 'r'

test.file_fixture('fixture/SConstruct.issue-3550', 'SConstruct')
test.file_fixture('fixture/substfile.in', 'substfile.in')

test.run(arguments='.')

test.must_match('substfile',
                r'''foo_path: Z:\mongo\build\install\bin
''', mode=match_mode)

test.pass_test()

==> scons_4.5.2%2Bdfsg.orig.tar.xz: scons-4.5.2+dfsg/test/textfile/issue-3550.py <==
#!/usr/bin/env python
#
# MIT License
#
# Copyright The SCons Foundation
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
# KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
# WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
# WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

"""
Test for GH Issue 3550

You can't pass a Windows path in a value to be interpolated, 
because SCons will try to pass it through re.sub which rejects
certain character sequences.
"""

import TestSCons

test = TestSCons.TestSCons()

match_mode = 'r'

test.file_fixture('fixture/SConstruct.issue-3550', 'SConstruct')
test.file_fixture('fixture/substfile.in', 'substfile.in')

test.run(arguments='.')

test.must_match('substfile',
                r'''foo_path: Z:\mongo\build\install\bin
''', mode=match_mode)

test.pass_test()
